==> pipewire-docs-1%3A1.0.3-1-aarch64.pkg.tar.xz: usr/share/doc/pipewire/html/page_pulse_modules.js <==
var page_pulse_modules =
[
    [ "ALSA Sink", "page_pulse_module_alsa_sink.html", null ],
    [ "ALSA Source", "page_pulse_module_alsa_source.html", null ],
    [ "Always Sink", "page_pulse_module_always_sink.html", null ],
    [ "Combine Sink", "page_pulse_module_combine_sink.html", null ],
    [ "Echo Cancel", "page_pulse_module_echo_cancel.html", null ],
    [ "GSettings", "page_pulse_module_gsettings.html", null ],
    [ "JackDBus Detect", "page_pulse_module_jackdbus_detect.html", null ],
    [ "LADSPA Sink", "page_pulse_module_ladspa_sink.html", null ],
    [ "LADSPA Source", "page_pulse_module_ladspa_source.html", null ],
    [ "Loopback", "page_pulse_module_loopback.html", null ],
    [ "Pulseaudio TCP Protocol", "page_pulse_module_native_protocol_tcp.html", null ],
    [ "Null Sink", "page_pulse_module_null_sink.html", null ],
    [ "Pipe Sink", "page_pulse_module_pipe_sink.html", null ],
    [ "Pipe Source", "page_pulse_module_pipe_source.html", null ],
    [ "RAOP Discover", "page_pulse_module_raop_discover.html", null ],
    [ "Remap Sink", "page_pulse_module_remap_sink.html", null ],
    [ "Remap Source", "page_pulse_module_remap_source.html", null ],
    [ "ROC Sink", "page_pulse_module_roc_sink.html", null ],
    [ "ROC Sink Input", "page_pulse_module_roc_sink_input.html", null ],
    [ "ROC Source", "page_pulse_module_roc_source.html", null ],
    [ "RTP Receiver", "page_pulse_module_rtp_recv.html", null ],
    [ "RTP Sender", "page_pulse_module_rtp_send.html", null ],
    [ "Simple TCP Protocol", "page_pulse_module_simple_protocol_tcp.html", null ],
    [ "Switch on Connect", "page_pulse_module_switch_on_connect.html", null ],
    [ "Tunnel Sink", "page_pulse_module_tunnel_sink.html", null ],
    [ "Tunnel Source", "page_pulse_module_tunnel_source.html", null ],
    [ "Virtual Sink", "page_pulse_module_virtual_sink.html", null ],
    [ "Virtual Source", "page_pulse_module_virtual_source.html", null ],
    [ "X11 Bell", "page_pulse_module_x11_bell.html", null ],
    [ "Zeroconf Discover", "page_pulse_module_zeroconf_discover.html", null ],
    [ "Zeroconf Publish", "page_pulse_module_zeroconf_publish.html", null ]
];

==> pipewire-docs-1%3A1.2.6-1-aarch64.pkg.tar.xz: usr/share/doc/pipewire/html/page_pulse_modules.js <==
var page_pulse_modules =
[
    [ "ALSA Sink", "page_pulse_module_alsa_sink.html", null ],
    [ "ALSA Source", "page_pulse_module_alsa_source.html", null ],
    [ "Always Sink", "page_pulse_module_always_sink.html", null ],
    [ "Combine Sink", "page_pulse_module_combine_sink.html", null ],
    [ "Device manager extension", "page_pulse_module_device_manager.html", null ],
    [ "Device restore extension", "page_pulse_module_device_restore.html", null ],
    [ "Echo Cancel", "page_pulse_module_echo_cancel.html", null ],
    [ "GSettings", "page_pulse_module_gsettings.html", null ],
    [ "JackDBus Detect", "page_pulse_module_jackdbus_detect.html", null ],
    [ "LADSPA Sink", "page_pulse_module_ladspa_sink.html", null ],
    [ "LADSPA Source", "page_pulse_module_ladspa_source.html", null ],
    [ "Loopback", "page_pulse_module_loopback.html", null ],
    [ "Pulseaudio TCP Protocol", "page_pulse_module_native_protocol_tcp.html", null ],
    [ "Null Sink", "page_pulse_module_null_sink.html", null ],
    [ "Pipe Sink", "page_pulse_module_pipe_sink.html", null ],
    [ "Pipe Source", "page_pulse_module_pipe_source.html", null ],
    [ "RAOP Discover", "page_pulse_module_raop_discover.html", null ],
    [ "Remap Sink", "page_pulse_module_remap_sink.html", null ],
    [ "Remap Source", "page_pulse_module_remap_source.html", null ],
    [ "ROC Sink", "page_pulse_module_roc_sink.html", null ],
    [ "ROC Sink Input", "page_pulse_module_roc_sink_input.html", null ],
    [ "ROC Source", "page_pulse_module_roc_source.html", null ],
    [ "RTP Receiver", "page_pulse_module_rtp_recv.html", null ],
    [ "RTP Sender", "page_pulse_module_rtp_send.html", null ],
    [ "Simple TCP Protocol", "page_pulse_module_simple_protocol_tcp.html", null ],
    [ "Stream restore extension", "page_pulse_module_stream_restore.html", null ],
    [ "Switch on Connect", "page_pulse_module_switch_on_connect.html", null ],
    [ "Tunnel Sink", "page_pulse_module_tunnel_sink.html", null ],
    [ "Tunnel Source", "page_pulse_module_tunnel_source.html", null ],
    [ "Virtual Sink", "page_pulse_module_virtual_sink.html", null ],
    [ "Virtual Source", "page_pulse_module_virtual_source.html", null ],
    [ "X11 Bell", "page_pulse_module_x11_bell.html", null ],
    [ "Zeroconf Discover", "page_pulse_module_zeroconf_discover.html", null ],
    [ "Zeroconf Publish", "page_pulse_module_zeroconf_publish.html", null ]
];
